@@ -19,12 +19,10 @@ package parser
 import (
 	"bytes"
 	"errors"
-	"fmt"
 	"io"
 	"io/fs"
 	"os"
 	"path"
-	"path/filepath"
 	"strings"
 
 	goast "go/ast"
@@ -51,6 +49,10 @@ func SetDebug(dbgFlags int) {
 	debugParseError = (dbgFlags & DbgFlagParseError) != 0
 }
 
+var (
+	ErrUnknownFileKind = errors.New("unknown file kind")
+)
+
 type FileSystem = fsx.FileSystem
 
 // -----------------------------------------------------------------------------
@@ -95,15 +97,9 @@ func ParseDirEx(fset *token.FileSet, path string, conf Config) (pkgs map[string]
 	return ParseFSDir(fset, fsx.Local, path, conf)
 }
 
-// ClassFileExt returns the classfile extension
-func ClassFileExt(path string) (ext string) {
-	ext = filepath.Ext(path)
-	if ext == ".gox" {
-		if c := filepath.Ext(path[:len(path)-4]); c != "" {
-			return c
-		}
-	}
-	return
+// ParseEntry calls ParseFSEntry by passing a local filesystem.
+func ParseEntry(fset *token.FileSet, filename string, src interface{}, conf Config) (f *ast.File, err error) {
+	return ParseFSEntry(fset, fsx.Local, filename, src, conf)
 }
 
 // ParseFSDir calls ParseFile for all files with names ending in ".gop" in the
@@ -118,8 +114,8 @@ func ClassFileExt(path string) (ext string) {
 // If the directory couldn't be read, a nil map and the respective error are
 // returned. If a parse error occurred, a non-nil but incomplete map and the
 // first error encountered are returned.
-func ParseFSDir(fset *token.FileSet, fs FileSystem, path string, conf Config) (pkgs map[string]*ast.Package, first error) {
-	list, err := fs.ReadDir(path)
+func ParseFSDir(fset *token.FileSet, fs FileSystem, dir string, conf Config) (pkgs map[string]*ast.Package, first error) {
+	list, err := fs.ReadDir(dir)
 	if err != nil {
 		return nil, err
 	}
@@ -133,7 +129,7 @@ func ParseFSDir(fset *token.FileSet, fs FileSystem, path string, conf Config) (p
 		}
 		fname := d.Name()
 		fnameRmGox := fname
-		ext := filepath.Ext(fname)
+		ext := path.Ext(fname)
 		var isProj, isClass, isNormalGox, useGoParser, rmGox bool
 		switch ext {
 		case ".gop":
@@ -145,8 +141,8 @@ func ParseFSDir(fset *token.FileSet, fs FileSystem, path string, conf Config) (p
 		case ".gox":
 			isClass = true
 			t := fname[:len(fname)-4]
-			if c := filepath.Ext(t); c != "" {
-				ext, fnameRmGox, rmGox = c, t, true
+			if c := path.Ext(t); c != "" {
+				fnameRmGox, rmGox = t, true
 			} else {
 				isNormalGox = true
 			}
@@ -154,10 +150,11 @@ func ParseFSDir(fset *token.FileSet, fs FileSystem, path string, conf Config) (p
 		default:
 			if !isNormalGox {
 				if isProj, isClass = conf.ClassKind(fnameRmGox); !isClass {
-					if rmGox {
-						return nil, fmt.Errorf("not found Go+ class by ext %q for %q", ext, fname)
+					if !rmGox { // unknown fileKind
+						continue
 					}
-					continue
+					// not found Go+ class by ext, but is a .gox file
+					isClass, isNormalGox = true, true
 				}
 			}
 		}
@@ -166,7 +163,7 @@ func ParseFSDir(fset *token.FileSet, fs FileSystem, path string, conf Config) (p
 			mode |= ParseGoPlusClass
 		}
 		if !strings.HasPrefix(fname, "_") && (conf.Filter == nil || filter(d, conf.Filter)) {
-			filename := fs.Join(path, fname)
+			filename := fs.Join(dir, fname)
 			if useGoParser {
 				if filedata, err := fs.ReadFile(filename); err == nil {
 					if src, err := goparser.ParseFile(fset, filename, filedata, goparser.Mode(conf.Mode)); err == nil {
@@ -181,11 +178,11 @@ func ParseFSDir(fset *token.FileSet, fs FileSystem, path string, conf Config) (p
 				} else {
 					first = err
 				}
-			} else if src, err := ParseFSFile(fset, fs, filename, nil, mode); err == nil {
-				src.IsProj, src.IsClass = isProj, isClass
-				src.IsNormalGox = isNormalGox
-				pkg := reqPkg(pkgs, src.Name.Name)
-				pkg.Files[filename] = src
+			} else if f, err := ParseFSFile(fset, fs, filename, nil, mode); err == nil {
+				f.IsProj, f.IsClass = isProj, isClass
+				f.IsNormalGox = isNormalGox
+				pkg := reqPkg(pkgs, f.Name.Name)
+				pkg.Files[filename] = f
 			} else if first == nil {
 				first = err
 			}
@@ -194,6 +191,50 @@ func ParseFSDir(fset *token.FileSet, fs FileSystem, path string, conf Config) (p
 	return
 }
 
+// ParseFSEntry parses the source code of a single Go+ source file and returns the corresponding ast.File node.
+// Compared to ParseFSFile, ParseFSEntry detects fileKind by its filename.
+func ParseFSEntry(fset *token.FileSet, fs FileSystem, filename string, src interface{}, conf Config) (f *ast.File, err error) {
+	fname := fs.Base(filename)
+	fnameRmGox := fname
+	ext := path.Ext(fname)
+	var isProj, isClass, isNormalGox, rmGox bool
+	switch ext {
+	case ".gop", ".go":
+	case ".gox":
+		isClass = true
+		t := fname[:len(fname)-4]
+		if c := path.Ext(t); c != "" {
+			fnameRmGox, rmGox = t, true
+		} else {
+			isNormalGox = true
+		}
+		fallthrough
+	default:
+		if !isNormalGox {
+			if conf.ClassKind == nil {
+				conf.ClassKind = defaultClassKind
+			}
+			if isProj, isClass = conf.ClassKind(fnameRmGox); !isClass {
+				if !rmGox {
+					return nil, ErrUnknownFileKind
+				}
+				// not found Go+ class by ext, but is a .gox file
+				isClass, isNormalGox = true, true
+			}
+		}
+	}
+	mode := conf.Mode
+	if isClass {
+		mode |= ParseGoPlusClass
+	}
+	f, err = ParseFSFile(fset, fs, filename, src, mode)
+	if err == nil {
+		f.IsProj, f.IsClass = isProj, isClass
+		f.IsNormalGox = isNormalGox
+	}
+	return
+}
+
 func filter(d fs.DirEntry, fn func(fs.FileInfo) bool) bool {
 	fi, err := d.Info()
 	return err != nil || fn(fi)
